aboutsummaryrefslogtreecommitdiffhomepage
path: root/src/gpu/gl/GrGLProgram.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/gpu/gl/GrGLProgram.h')
-rw-r--r--src/gpu/gl/GrGLProgram.h5
1 files changed, 3 insertions, 2 deletions
diff --git a/src/gpu/gl/GrGLProgram.h b/src/gpu/gl/GrGLProgram.h
index 513bf75d23..8b494c8cef 100644
--- a/src/gpu/gl/GrGLProgram.h
+++ b/src/gpu/gl/GrGLProgram.h
@@ -199,10 +199,11 @@ private:
GrGLuint fGShaderID;
GrGLuint fFShaderID;
GrGLuint fProgramID;
// The matrix sent to GL is determined by both the client's matrix and
// the size of the viewport.
SkMatrix fViewMatrix;
SkISize fViewportSize;
+ GrSurfaceOrigin fOrigin;
// these reflect the current values of uniforms (GL uniform values travel with program)
GrColor fColor;
@@ -199,10 +199,11 @@ private:
GrGLuint fFShaderID;
GrGLuint fProgramID;
- // The matrix sent to GL is determined by both the client's matrix and
- // the size of the viewport.
+ // The matrix sent to GL is determined by the client's matrix,
+ // the size of the viewport, and the origin of the render target.
SkMatrix fViewMatrix;
SkISize fViewportSize;